==> quidproquo-actionprocessor-awslambda-0.0.211.tgz: package/lib/esm/getActionProcessor/core/userDirectory/getUserDirectoryRespondToAuthChallengeActionProcessor.js <==
import { actionResult, qpqCoreUtils, UserDirectoryActionType, AuthenticateUserChallenge, } from 'quidproquo-core';
import { getCFExportNameUserPoolIdFromConfig, getCFExportNameUserPoolClientIdFromConfig, } from '../../../awsNamingUtils';
import { getExportedValue } from '../../../logic/cloudformation/getExportedValue';
import { respondToAuthChallengeChallenge } from '../../../logic/cognito/respondToAuthChallengeChallenge';
const anyAuthChallengeToCognitoAttributes = (authChallenge) => {
    switch (authChallenge.challenge) {
        case AuthenticateUserChallenge.NEW_PASSWORD_REQUIRED:
            return {
                NEW_PASSWORD: authChallenge.newPassword,
            };
        default:
            return {};
    }
};
const getUserDirectoryRespondToAuthChallengeActionProcessor = (qpqConfig) => {
    return async ({ userDirectoryName, authChallenge }) => {
        const region = qpqCoreUtils.getApplicationModuleDeployRegion(qpqConfig);
        const userPoolId = await getExportedValue(getCFExportNameUserPoolIdFromConfig(userDirectoryName, qpqConfig), region);
        const userPoolClientId = await getExportedValue(getCFExportNameUserPoolClientIdFromConfig(userDirectoryName, qpqConfig), region);
        const response = await respondToAuthChallengeChallenge(userPoolId, userPoolClientId, region, authChallenge.username, authChallenge.session, anyAuthChallengeToCognitoAttributes(authChallenge));
        return actionResult(response);
    };
};
export default (qpqConfig) => {
    return {
        [UserDirectoryActionType.RespondToAuthChallenge]: getUserDirectoryRespondToAuthChallengeActionProcessor(qpqConfig),
    };
};

==> quidproquo-actionprocessor-awslambda-0.0.220.tgz: package/lib/esm/getActionProcessor/core/userDirectory/getUserDirectoryRespondToAuthChallengeActionProcessor.js <==
import { actionResult, qpqCoreUtils, UserDirectoryActionType, AuthenticateUserChallenge, } from 'quidproquo-core';
import { getCFExportNameUserPoolIdFromConfig, getCFExportNameUserPoolClientIdFromConfig } from '../../../awsNamingUtils';
import { getExportedValue } from '../../../logic/cloudformation/getExportedValue';
import { respondToAuthChallengeChallenge } from '../../../logic/cognito/respondToAuthChallengeChallenge';
import { ChallengeNameType } from '@aws-sdk/client-cognito-identity-provider';
const anyAuthChallengeToCognitoAttributes = (authChallenge) => {
    switch (authChallenge.challenge) {
        case AuthenticateUserChallenge.NEW_PASSWORD_REQUIRED:
            return {
                NEW_PASSWORD: authChallenge.newPassword,
            };
        case AuthenticateUserChallenge.CUSTOM_CHALLENGE:
            return {
                ANSWER: JSON.stringify(authChallenge.challengeAnswer),
            };
        default:
            return {};
    }
};
const anyAuthChallengeToCognitoChallengeName = (authChallenge) => {
    switch (authChallenge.challenge) {
        case AuthenticateUserChallenge.NEW_PASSWORD_REQUIRED:
            return ChallengeNameType.NEW_PASSWORD_REQUIRED;
        case AuthenticateUserChallenge.CUSTOM_CHALLENGE:
            return ChallengeNameType.CUSTOM_CHALLENGE;
        default:
            throw new Error(`Unknown challenge`);
    }
};
const getUserDirectoryRespondToAuthChallengeActionProcessor = (qpqConfig) => {
    return async ({ userDirectoryName, authChallenge }) => {
        const region = qpqCoreUtils.getApplicationModuleDeployRegion(qpqConfig);
        const userPoolId = await getExportedValue(getCFExportNameUserPoolIdFromConfig(userDirectoryName, qpqConfig), region);
        const userPoolClientId = await getExportedValue(getCFExportNameUserPoolClientIdFromConfig(userDirectoryName, qpqConfig), region);
        const response = await respondToAuthChallengeChallenge(userPoolId, userPoolClientId, region, authChallenge.username, authChallenge.session, anyAuthChallengeToCognitoChallengeName(authChallenge), anyAuthChallengeToCognitoAttributes(authChallenge));
        return actionResult(response);
    };
};
export default (qpqConfig) => {
    return {
        [UserDirectoryActionType.RespondToAuthChallenge]: getUserDirectoryRespondToAuthChallengeActionProcessor(qpqConfig),
    };
};
